@@ -18,14 +18,12 @@
 
 #include "typeslistitem.h"
 
-class QLabel;
 class QTreeWidget;
 class QTreeWidgetItem;
 class QPushButton;
 class KLineEdit;
 class FileTypeDetails;
 class FileGroupDetails;
-class QStackedWidget;
 
 class FileTypesView : public KCModule
 {
@@ -46,7 +44,7 @@ protected Q_SLOTS:
     void slotFilter(const QString &patternFilter);
     void setDirty(bool state);
 
-    void slotDatabaseChanged(const QStringList &changedResources);
+    void slotDatabaseChanged();
     void slotEmbedMajor(const QString &major, bool &embed);
 
 private:
