@@ -1,32 +1,19 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2003 David Faure <faure@kde.org>
-   Copyright (C) 2002 Daniel Molkentin <molkentin@kde.org>
+   SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+   SPDX-FileCopyrightText: 2003 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2002 Daniel Molkentin <molkentin@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-only
 */
 
 // Own
 #include "kservicelistwidget.h"
 
 // Qt
-#include <QBoxLayout>
-#include <QDebug>
-#include <QLayout>
+#include <QHBoxLayout>
 #include <QPushButton>
 #include <QStandardPaths>
+#include <QVBoxLayout>
 
 // KDE
 #include <klocalizedstring.h>
@@ -52,12 +39,20 @@ KServiceListItem::KServiceListItem(const KService::Ptr &pService, int kind)
     setIcon(QIcon::fromTheme(pService->icon()));
 
     if (!pService->isApplication()) {
-        localPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kservices5/") + desktopPath;
+        localPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kservices" QT_STRINGIFY(QT_VERSION_MAJOR))
+            + QLatin1Char('/') + desktopPath;
     } else {
         localPath = pService->locateLocal();
     }
 }
 
+PluginListItem::PluginListItem(const KPluginMetaData &metaData)
+    : QListWidgetItem()
+{
+    setText(i18n("%1 (%2)", metaData.name(), metaData.pluginId()));
+    setIcon(QIcon::fromTheme(metaData.iconName()));
+}
+
 KServiceListWidget::KServiceListWidget(int kind, QWidget *parent)
     : QGroupBox(kind == SERVICELIST_APPLICATIONS ? i18n("Application Preference Order") : i18n("Services Preference Order"), parent)
     , m_kind(kind)
@@ -195,7 +190,7 @@ void KServiceListWidget::promoteService()
 
     updatePreferredServices();
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KServiceListWidget::demoteService()
@@ -216,7 +211,7 @@ void KServiceListWidget::demoteService()
 
     updatePreferredServices();
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KServiceListWidget::addService()
@@ -272,7 +267,7 @@ void KServiceListWidget::addService()
 
     updatePreferredServices();
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KServiceListWidget::editService()
@@ -346,7 +341,7 @@ void KServiceListWidget::editService()
 
     updatePreferredServices();
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KServiceListWidget::removeService()
@@ -361,7 +356,7 @@ void KServiceListWidget::removeService()
         delete servicesLB->takeItem(selected);
         updatePreferredServices();
 
-        emit changed(true);
+        Q_EMIT changed(true);
     }
 
     // Update buttons and service list again (e.g. to re-add "None")
